==> chromium_81.0.4044.62.orig.tar.xz: chromium-81.0.4044.62/chrome/browser/resources/management/management_browser_proxy.js <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import {addSingletonGetter, sendWithPromise} from 'chrome://resources/js/cr.m.js';

/**
 * @typedef {{
 *   name: string,
 *   permissions: !Array<string>
 * }}
 */
export let Extension;

/** @enum {string} */
export const ReportingType = {
  SECURITY: 'security',
  DEVICE: 'device',
  USER: 'user',
  USER_ACTIVITY: 'user-activity',
  EXTENSIONS: 'extensions'
};

/**
 * @typedef {{
 *   messageId: string,
 *   reportingType: !ReportingType,
 * }}
 */
export let BrowserReportingResponse;

/**
 * @typedef {{
 *   browserManagementNotice: string,
 *   extensionReportingTitle: string,
 *   pageSubtitle: string,
 *   managed: boolean,
 *   overview: string,
 *   customerLogo: string,
 *   threatProtectionDescription: string
 * }}
 */
let ManagedDataResponse;

/**
 * @typedef {{
 *  title: string,
 *  permission: string
 * }}
 */
let ThreatProtectionPermission;

/**
 * @typedef {{
 *   info: !Array<!ThreatProtectionPermission>,
 *   description: string
 * }}
 */
export let ThreatProtectionInfo;

// <if expr="chromeos">
/**
 * @enum {string} Look at ToJSDeviceReportingType usage in
 *    management_ui_handler.cc for more details.
 */
export const DeviceReportingType = {
  SUPERVISED_USER: 'supervised user',
  DEVICE_ACTIVITY: 'device activity',
  STATISTIC: 'device statistics',
  DEVICE: 'device',
  LOGS: 'logs',
  PRINT: 'print',
  CROSTINI: 'crostini',
  USERNAME: 'username',
  EXTENSION: 'extension',
  ANDROID_APPLICATION: 'android application'
};


/**
 * @typedef {{
 *   messageId: string,
 *   reportingType: !DeviceReportingType,
 * }}
 */
export let DeviceReportingResponse;
// </if>

/** @interface */
export class ManagementBrowserProxy {
  /** @return {!Promise<!Array<!Extension>>} */
  getExtensions() {}

  // <if expr="chromeos">
  /**
   * @return {!Promise<boolean>} Boolean describing trust root configured
   *     or not.
   */
  getLocalTrustRootsInfo() {}

  /**
   * @return {!Promise<!Array<DeviceReportingResponse>>} List of
   *     items to display in device reporting section.
   */
  getDeviceReportingInfo() {}
  // </if>

  /** @return {!Promise<!ManagedDataResponse>} */
  getContextualManagedData() {}

  /** @return {!Promise<!ThreatProtectionInfo>} */
  getThreatProtectionInfo() {}

  /**
   * @return {!Promise<!Array<!BrowserReportingResponse>>} The list
   *     of browser reporting info messages.
   */
  initBrowserReportingInfo() {}
}

/** @implements {ManagementBrowserProxy} */
export class ManagementBrowserProxyImpl {
  /** @override */
  getExtensions() {
    return sendWithPromise('getExtensions');
  }

  // <if expr="chromeos">
  /** @override */
  getLocalTrustRootsInfo() {
    return sendWithPromise('getLocalTrustRootsInfo');
  }

  /** @override */
  getDeviceReportingInfo() {
    return sendWithPromise('getDeviceReportingInfo');
  }
  // </if>

  /** @override */
  getContextualManagedData() {
    return sendWithPromise('getContextualManagedData');
  }

  /** @override */
  getThreatProtectionInfo() {
    return sendWithPromise('getThreatProtectionInfo');
  }

  /** @override */
  initBrowserReportingInfo() {
    return sendWithPromise('initBrowserReportingInfo');
  }
}

addSingletonGetter(ManagementBrowserProxyImpl);

// Export |ManagementBrowserProxyImpl| on |window| so that it can be accessed by
// management_ui_browsertest.cc
window.ManagementBrowserProxyImpl = ManagementBrowserProxyImpl;

==> chromium-93.0.4535.3.tar.xz: chromium-93.0.4535.3/chrome/browser/resources/management/management_browser_proxy.js <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import {addSingletonGetter, sendWithPromise} from 'chrome://resources/js/cr.m.js';

/**
 * @typedef {{
 *   name: string,
 *   permissions: !Array<string>
 * }}
 */
export let Extension;

/** @enum {string} */
export const ReportingType = {
  SECURITY: 'security',
  DEVICE: 'device',
  USER: 'user',
  USER_ACTIVITY: 'user-activity',
  EXTENSIONS: 'extensions'
};

/**
 * @typedef {{
 *   messageId: string,
 *   reportingType: !ReportingType,
 * }}
 */
export let BrowserReportingResponse;

/**
 * @typedef {{
 *   browserManagementNotice: string,
 *   extensionReportingTitle: string,
 *   managedWebsitesSubtitle: string,
 *   pageSubtitle: string,
 *   managed: boolean,
 *   overview: string,
 *   customerLogo: string,
 *   threatProtectionDescription: string,
 *   showUpdateRequiredEol: boolean,
 *   eolMessage: string,
 *   eolAdminMessage: string,
 *   showProxyServerPrivacyDisclosure: boolean
 * }}
 */
let ManagedDataResponse;

/**
 * @typedef {{
 *  title: string,
 *  permission: string
 * }}
 */
let ThreatProtectionPermission;

/**
 * @typedef {{
 *   info: !Array<!ThreatProtectionPermission>,
 *   description: string
 * }}
 */
export let ThreatProtectionInfo;

// <if expr="chromeos">
/**
 * @enum {string} Look at ToJSDeviceReportingType usage in
 *    management_ui_handler.cc for more details.
 */
export const DeviceReportingType = {
  SUPERVISED_USER: 'supervised user',
  DEVICE_ACTIVITY: 'device activity',
  STATISTIC: 'device statistics',
  DEVICE: 'device',
  CRASH_REPORT: 'crash report',
  APP_INFO_AND_ACTIVITY: 'app info and activity',
  LOGS: 'logs',
  PRINT: 'print',
  PRINT_JOBS: 'print jobs',
  DLP_EVENTS: 'dlp events',
  CROSTINI: 'crostini',
  USERNAME: 'username',
  EXTENSION: 'extension',
  ANDROID_APPLICATION: 'android application',
};


/**
 * @typedef {{
 *   messageId: string,
 *   reportingType: !DeviceReportingType,
 * }}
 */
export let DeviceReportingResponse;
// </if>

/** @interface */
export class ManagementBrowserProxy {
  /** @return {!Promise<!Array<!Extension>>} */
  getExtensions() {}

  /** @return {!Promise<!Array<!String>>} */
  getManagedWebsites() {}

  // <if expr="chromeos">
  /**
   * @return {!Promise<boolean>} Boolean describing trust root configured
   *     or not.
   */
  getLocalTrustRootsInfo() {}

  /**
   * @return {!Promise<!Array<DeviceReportingResponse>>} List of
   *     items to display in device reporting section.
   */
  getDeviceReportingInfo() {}

  /**
   * @return {!Promise<boolean>} Boolean describing Plugin VM data collection
   *     enabled or not.
   */
  getPluginVmDataCollectionStatus() {}
  // </if>

  /** @return {!Promise<!ManagedDataResponse>} */
  getContextualManagedData() {}

  /** @return {!Promise<!ThreatProtectionInfo>} */
  getThreatProtectionInfo() {}

  /**
   * @return {!Promise<!Array<!BrowserReportingResponse>>} The list
   *     of browser reporting info messages.
   */
  initBrowserReportingInfo() {}
}

/** @implements {ManagementBrowserProxy} */
export class ManagementBrowserProxyImpl {
  /** @override */
  getExtensions() {
    return sendWithPromise('getExtensions');
  }

  /** @override */
  getManagedWebsites() {
    return sendWithPromise('getManagedWebsites');
  }

  // <if expr="chromeos">
  /** @override */
  getLocalTrustRootsInfo() {
    return sendWithPromise('getLocalTrustRootsInfo');
  }

  /** @override */
  getDeviceReportingInfo() {
    return sendWithPromise('getDeviceReportingInfo');
  }

  /** @override */
  getPluginVmDataCollectionStatus() {
    return sendWithPromise('getPluginVmDataCollectionStatus');
  }
  // </if>

  /** @override */
  getContextualManagedData() {
    return sendWithPromise('getContextualManagedData');
  }

  /** @override */
  getThreatProtectionInfo() {
    return sendWithPromise('getThreatProtectionInfo');
  }

  /** @override */
  initBrowserReportingInfo() {
    return sendWithPromise('initBrowserReportingInfo');
  }
}

addSingletonGetter(ManagementBrowserProxyImpl);

// Export |ManagementBrowserProxyImpl| on |window| so that it can be accessed by
// management_ui_browsertest.cc
window.ManagementBrowserProxyImpl = ManagementBrowserProxyImpl;
